@@ -6,7 +6,7 @@ TODO:
 """
 
 from .imports import *
-from . import _auth, _lektier, _skema, _modul, _opgaver, _beskeder, _informationer
+from . import _auth, _lektier, _skema, _modul, _opgaver, _beskeder, _informationer, _filer
 
 class sdk:
     def __init__(self, brugernavn, adgangskode, skoleId, base64Cookie=None):
@@ -51,4 +51,7 @@ class sdk:
         return _informationer.informationer(self)
 
     def fåElev(self, elevId):
-        return _informationer.fåElev(self, elevId)
\ No newline at end of file
+        return _informationer.fåElev(self, elevId)
+
+    def fåFil(self, filUrl):
+        return _filer.fåFil(self, filUrl)
\ No newline at end of file
